@@ -37,16 +37,45 @@ struct generalitemstruct
    long long oucache;
 };
 
+/*! \brief What is known about a user.
+*/
 struct userinfostruct
 {
-   //! The ID of the user as found in the input file.
-   char id[MAX_USER_LEN];
-   //! \c True if the ID is in fact the IP address from which the user connected.
-   bool id_is_ip;
-   //! The name of the user to display in the report.
-   char label[MAX_USER_LEN];
-   //! The mangled name to use in file names of that user.
-   char filename[MAX_USER_FNAME_LEN];
+	//! The ID of the user as found in the input file.
+	char id[MAX_USER_LEN];
+	//! \c True if the ID is in fact the IP address from which the user connected.
+	bool id_is_ip;
+	//! \c True if the user doesn't have a report file.
+	bool no_report;
+	//! The name of the user to display in the report.
+	char label[MAX_USER_LEN];
+	//! The mangled name to use in file names of that user.
+	char filename[MAX_USER_FNAME_LEN];
+	//! \c True if this user is in the topuser list.
+	int topuser;
+	//! A general purpose flag that can be set when scanning the user's list.
+	int flag;
+};
+
+//! Scan through the known users.
+typedef struct userscanstruct *userscan;
+
+/*! \brief Global statistics
+*/
+struct globalstatstruct
+{
+	//! Total number of accesses.
+	long long int nacc;
+	//! Total number of bytes.
+	long long int nbytes;
+	//! Total time spent processing the requests.
+	long long int elap;
+	//! Amount of data fetched from the cache.
+	long long int incache;
+	//! Amount of data not fetched from the cache.
+	long long int oucache;
+	//! The number of users in the topuser list.
+	int totuser;
 };
 
 // auth.c
@@ -113,7 +142,7 @@ void index_only(const char *dirname,int debug);
 
 // ip2name.c
 void ip2name(char *ip,int ip_len);
-void name2ip(char *name);
+void name2ip(char *name,int name_size);
 
 // lastlog.c
 void mklastlog(const char *outdir);
@@ -130,13 +159,17 @@ void make_index(void);
 // realtime.c
 void realtime(void);
 
+// redirector.c
+void redirector_log(void);
+void redirector_report(void);
+
 // repday.c
 void report_day(const struct userinfostruct *user);
 
 // report.c
-void gravatmp(const struct userinfostruct *uinfo, const char *oldurl, long long int nacc, long long int nbytes, const char *oldmsg, long long int nelap, int indexonly, long long int incache, long long int oucache);
 void gerarel(void);
 int ger_read(char *buffer,struct generalitemstruct *item,const char *filename);
+void totalger(FILE *fp_gen,const char *filename);
 
 // siteuser.c
 void siteuser(void);
@@ -146,17 +179,11 @@ void smartfilter_report(void);
 
 // sort.c
 void sort_users_log(const char *tmp, int debug);
-void tmpsort(void);
+void tmpsort(const struct userinfostruct *uinfo);
 void sort_labels(const char **label,const char **order);
 
 // splitlog.c
-void splitlog(const char *arq, char *df, int dfrom, int duntil, int convert);
-
-// squidguard_log.c
-void squidguard_log(void);
-
-// squidguard_report.c
-void squidguard_report(void);
+void splitlog(const char *arq, const char *df, int dfrom, int duntil, int convert, const char *splitprefix);
 
 // topsites.c
 void topsites(void);
@@ -165,10 +192,13 @@ void topsites(void);
 void topuser(void);
 
 // totday.c
-void day_totalize(const char *tmp, const struct userinfostruct *uinfo, int indexonly);
+void day_totalize(const char *tmp, const struct userinfostruct *uinfo);
 
-// totger.c
-int totalger(const char *dirname, int debug, const char *outdir);
+// url.c
+void read_hostalias(const char *Filename);
+void free_hostalias(void);
+const char *process_url(char *url,bool full_url);
+void url_hostname(const char *url,char *hostname,int hostsize);
 
 // usage.c
 void usage(const char *prog);
@@ -181,6 +211,10 @@ void useragent(void);
 void userinfo_free(void);
 /*@shared@*/struct userinfostruct *userinfo_find_from_file(const char *filename);
 /*@shared@*/struct userinfostruct *userinfo_find_from_id(const char *id);
+userscan userinfo_startscan(void);
+void userinfo_stopscan(userscan uscan);
+struct userinfostruct *userinfo_advancescan(userscan uscan);
+void userinfo_clearflag(void);
 
 // usertab.c
 void init_usertab(const char *UserTabFile);
@@ -195,6 +229,7 @@ __attribute__((warn_unused_result)) int getword_limit(/*@out@*/char *word, int l
 __attribute__((warn_unused_result)) int getword_multisep(/*@out@*/char *word, int limit, struct getwordstruct *gwarea, char stop);
 __attribute__((warn_unused_result)) int getword_skip(int limit, struct getwordstruct *gwarea, char stop);
 __attribute__((warn_unused_result)) int getword_atoll(/*@out@*/long long int *number, struct getwordstruct *gwarea, char stop);
+__attribute__((warn_unused_result)) int getword_atoi(/*@out@*/int *number, struct getwordstruct *gwarea, char stop);
 __attribute__((warn_unused_result)) int getword_ptr(char *orig_line,/*@out@*/char **word, struct getwordstruct *gwarea, char stop);
 long long int my_atoll (const char *nptr);
 int is_absolute(const char *path);
@@ -212,26 +247,27 @@ void fixendofline(char *str);
 void show_info(FILE *fp_ou);
 void show_sarg(FILE *fp_ou, int depth);
 void write_logo_image(FILE *fp_ou);
-void write_html_head(FILE *fp_ou, const char *page_title);
-void write_html_header(FILE *fp_ou, int depth, const char *title);
+void write_html_head(FILE *fp_ou, int depth, const char *page_title,int javascript);
+void write_html_header(FILE *fp_ou, int depth, const char *title,int javascript);
 void close_html_header(FILE *fp_ou);
 __attribute__((warn_unused_result)) int write_html_trailer(FILE *fp_ou);
 void output_html_string(FILE *fp_ou,const char *str,int maxlen);
 void output_html_url(FILE *fp_ou,const char *url);
+void output_html_link(FILE *fp_ou,const char *url,int maxlen);
 void debuga(const char *msg,...) __attribute__((format(printf,1,2)));
-void debugaz(const char *head, const char *msg);
+void debugaz(const char *msg,...) __attribute__((format(printf,1,2)));
 void my_lltoa(unsigned long long int n, char *s, int ssize, int len);
 char *get_size(const char *path, const char *file);
-void url_hostname(const char *url,char *hostname,int hostsize);
 void url_module(const char *url, char *w2);
 void url_to_file(const char *url,char *file,int filesize);
+void safe_strcpy(char *dest,const char *src,int length);
 void strip_latin(char *line);
 char *buildtime(long long int elap);
-void obtdate(const char *dirname, const char *name, char *data);
+int obtdate(const char *dirname, const char *name, char *data);
 void formatdate(char *date,int date_size,int year,int month,int day,int hour,int minute,int second,int dst);
 void computedate(int year,int month,int day,struct tm *t);
 int obtuser(const char *dirname, const char *name);
-void obttotal(const char *dirname, const char *name, char *tbytes, int nuser, char *media);
+void obttotal(const char *dirname, const char *name, int nuser, long long int *tbytes, long long int *media);
 void version(void);
 int vercode(const char *code);
 void load_excludecodes(const char *ExcludeCodes);
@@ -251,3 +287,4 @@ void zdate(char *ftime,int ftimesize, const char *DateFormat);
 char *get_param_value(const char *param,char *line);
 int compar( const void *, const void * );
 void unlinkdir(const char *dir,int contentonly);
+int extract_address_mask(const char *buf,const char **text,unsigned char *ipv4,unsigned short int *ipv6,int *nbits,const char **next);
